@@ -152,31 +152,35 @@ def __init__(self, *args, **kwargs):
     for i in self.__column__[len(args):]:
         self.__dict__[i] = kwargs.get(i)
 
-    self.__dict__['_changed'] = set()
+    self.__dict__['_updated'] = set()
 
 def __setattr__(self, name, value):
     dc = self.__dict__
-    if name[0] != '_':
-        fields = self.__column__
-        if name in fields:
-            dc_value = dc[name]
-            if dc_value is None:
-                self._changed.add(name)
-            else:
-                if value is not None:
-                    value = type(dc_value)(value)
-                if dc_value != value:
-                    self._changed.add(name)
-    dc[name] = value
+    if name[0] != '_' and name in self.__column__:
+        dc_value = dc[name]
+        if dc_value is None:
+            self._updated.add(name)
+        else:
+            if value is not None:
+                value = type(dc_value)(value)
+            if dc_value != value:
+                self._updated.add(name)
+        dc[name] = value
+    else:
+        attr = getattr(self.__class__, name, None)
+        if attr and hasattr(attr, "fset"):
+            attr.fset(self, value)
+        else:
+            dc[name] = value
 
 def _update(self):
     query = [
         'UPDATE %s SET ' % self.__table__,
-        ','.join(['`%s`=%%s'%f for f in self._changed]),
+        ','.join(['`%s`=%%s'%f for f in self._updated]),
         ' WHERE id=%s '
     ]
 
-    values = [getattr(self, f) for f in self._changed]
+    values = [getattr(self, f) for f in self._updated]
     values.append(self.id)
 
     cursor = Query.execute(" ".join(query), values, self.__db__)
@@ -208,9 +212,9 @@ def _save(self):
     if self._is_new:
         self._insert()
         self._is_new = False
-    elif self._changed:
+    elif self._updated:
         self._update()
-    self._changed.clear()
+    self._updated.clear()
     return self
 
 
@@ -301,7 +305,7 @@ Model 定义如下
 
 #. 获取最大的id值 ::
 
-        UserMail.max_count()
+        UserMail.max_id()
 
     等价于 SQL ::
 
