@@ -2,7 +2,7 @@
 from intstr import IntStr
 
 redis_keyer = IntStr(
-'!"#$%&()+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ\\^_`abcdefghijklmnopqrstuvwxyz{|}~'
+'!"#$&()+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ^_`abcdefghijklmnopqrstuvwxyz{|}~'
 )
 
 REDIS_KEY_ID = 'RedisKeyId'
@@ -26,7 +26,9 @@ class RedisKey(object):
                 _key = redis.hget(REDIS_KEY, key)
                 if _key is None:
                     id = redis.incr(REDIS_KEY_ID)
-                    _key = redis_keyer.encode(id)+"'"+name
+                    _key = redis_keyer.encode(id)
+                    if name and "%" in name:
+                        _key = _key+"'"+name
                     p = redis.pipeline()
                     p.hset(REDIS_KEY, key, _key)
                     p.hset(REDIS_ID_KEY, _key, key)
